@@ -1,8 +1,9 @@
-from os import system
-system("pip install getkey;pip install AnsiPrint;")
-
-from getkey import getkey
-from AnsiPrint import *
+try:
+    from getkey import getkey
+    from AnsiPrint import *
+except ModuleNotFoundError:
+    from os import system
+    system("pip install getkey;pip install AnsiPrint;")
 
 def readpass(prompt,replacement=None):
     class ReplacementLengthError(Exception):
